paralelocs_qlikapi.method package — Paralelo CS Qlik API SDK for Python 0.2.5 documentation

# paralelocs_qlikapi.method package

## paralelocs_qlikapi.method.app module

class `paralelocs_qlikapi.method.app.` `App`(auth=None, session=None)

  Bases: `paralelocs_qlikapi.method.base.DefaultMethods`

  Classe para trabalhar com o recurso APP da API do QLIK

  `add_tag`(appid, tagname)
  `copy`(id)

    DESPUBLICAR APP

  `post`(path, name, filename)
  `publish_to_stream`(appid, streamname)

    PUBLICAR APP NA STREAM

  `reload`(name)
  `unpublish`(id)

    DESPUBLICAR APP

## paralelocs_qlikapi.method.base module

class `paralelocs_qlikapi.method.base.` `Base`(auth=None, session=None)

  Bases: `object`

  Classe base para os métodos da API

  `get`()
  `post`()
  `search`()

class `paralelocs_qlikapi.method.base.` `DefaultMethods`(auth=None, session=None)

  Bases: `paralelocs_qlikapi.method.base.Base`

  `delete`(id)
  `get`()
  `search`(name, params=None)
  `search_by_id`(id)
  `send`(method=None, resource=None, headers=None, data=None, params=None)

## paralelocs_qlikapi.method.reloadtask module

class `paralelocs_qlikapi.method.reloadtask.` `Task`(auth=None, session=None)

  Bases: `paralelocs_qlikapi.method.base.DefaultMethods`

  Classe para trabalhar com o recurso APP da API do QLIK

  `create_body_dict`()
  `create_composite_events_dict`(triggername, tasks)
  `create_daily`(appid, taskname, startdate)
  `create_hourly`(appid, taskname, startdate, after)
  `create_schema_events_dict`(taskname, startdate, expirationDate='9999-01-01T00:00:00.000', timeZone='America/New_York', incrementDescription='0 0 1 0')
  `create_task_dict`(appid, taskname, taskSessionTimeout=1440, maxRetries=0, enable=True)
  `create_trigger`(appid, taskname, triggername='Load sucessfully', tasks=[], **kwargs)

    Tasks is a list of task with id tasks [{‘id’:’1212sdsad-asdsad-asd’}, {‘id’:’121212-dsad-asas’}]

  `reload`(name)

## paralelocs_qlikapi.method.stream module

class `paralelocs_qlikapi.method.stream.` `Stream`(auth=None, session=None)

  Bases: `paralelocs_qlikapi.method.base.DefaultMethods`

  Classe para trabalhar com o recurso TAG da API do QLIK

  `post`(name)

## paralelocs_qlikapi.method.tag module

class `paralelocs_qlikapi.method.tag.` `Tag`(auth=None, session=None)

  Bases: `paralelocs_qlikapi.method.base.DefaultMethods`

  Classe para trabalhar com o recurso TAG da API do QLIK

  `post`(name)

## paralelocs_qlikapi.method.task module

class `paralelocs_qlikapi.method.task.` `Task`(auth=None, session=None)

  Bases: `paralelocs_qlikapi.method.base.DefaultMethods`

  Classe para trabalhar com o recurso APP da API do QLIK

  `start_by_id`(id)
  `start_by_name`(name)